summaryrefslogtreecommitdiffstats
path: root/tools/releasetools/common.py
diff options
context:
space:
mode:
Diffstat (limited to 'tools/releasetools/common.py')
-rw-r--r--tools/releasetools/common.py23
1 files changed, 16 insertions, 7 deletions
diff --git a/tools/releasetools/common.py b/tools/releasetools/common.py
index cd35023..26cc674 100644
--- a/tools/releasetools/common.py
+++ b/tools/releasetools/common.py
@@ -1490,18 +1490,27 @@ fi
'bonus_args': bonus_args}
# The install script location moved from /system/etc to /system/bin
# in the L release. Parse the init.rc file to find out where the
# target-files expects it to be, and put it there.
sh_location = "etc/install-recovery.sh"
- try:
- with open(os.path.join(input_dir, "BOOT", "RAMDISK", "init.rc")) as f:
+ found = False
+ init_rc_dir = os.path.join(input_dir, "BOOT", "RAMDISK")
+ init_rc_files = os.listdir(init_rc_dir)
+ for init_rc_file in init_rc_files:
+ if (not init_rc_file.startswith('init.') or
+ not init_rc_file.endswith('.rc')):
+ continue
+
+ with open(os.path.join(init_rc_dir, init_rc_file)) as f:
for line in f:
m = re.match(r"^service flash_recovery /system/(\S+)\s*$", line)
if m:
sh_location = m.group(1)
- print("putting script in", sh_location)
+ found = True
break
- except (OSError, IOError) as e:
- print("failed to read init.rc: %s" % e)
+ if found:
+ break
+
+ print("putting script in", sh_location)
- output_sink(sh_location, sh) \ No newline at end of file
+ output_sink(sh_location, sh)
@@ -1490,18 +1490,27 @@ fi
'bonus_args': bonus_args}
# The install script location moved from /system/etc to /system/bin
- # in the L release. Parse the init.rc file to find out where the
+ # in the L release. Parse init.*.rc files to find out where the
# target-files expects it to be, and put it there.
sh_location = "etc/install-recovery.sh"